/**
 * @file Slideshows.
 * Uses Drupal.behaviors
 * @see customer/README.md
 * @see https://www.drupal.org/docs/8/api/javascript-api/javascript-api-overview
 */

'use strict';

(function ($, Drupal, drupalSettings) {

  Drupal.behaviors.entitySlideshow = {

    attach: function (context) {
      var defaultSettings = {
        speed: 300,
        dots: false,
        adaptiveHeight: true
      };

      var galleryElts = document.querySelectorAll('.entity-gallery-slideshow');
      once('entity-gallery-slideshow', galleryElts).forEach(function (gallery) {
        var $slideshow = $(gallery);
        var settingsSpecific = {
          slidesToShow: 1,
          slidesToScroll: 1,
          initialSlide: $slideshow.data('slide')
        };

        if (drupalSettings.egs.pager === '1') {
          slickPager($slideshow);
        }

        var settings = $.extend({}, defaultSettings, settingsSpecific);

        $slideshow.slick(settings);
      });

      // Generate and display pager.
      function slickPager($slideshow) {
        var $pager;

        $slideshow.on('init', function (event, slick) {
          var total = slick.slideCount;
          var current = parseInt(slick.currentSlide) + 1;

          $pager = $('<div class="entity-gallery-slideshow-pager ' +
            'slick-pager"><span class="slick-pager-current">' + current +
            '</span>/' + total + '</div>');

          initPager($pager, $slideshow);
        });

        $slideshow.on('afterChange', function (event, slick, currentSlide) {
          var current = slick.currentSlide + 1;
          $slideshow.find('.slick-pager-current').text(current);
        });

        // Rewrite the pagination which disappeared when resizing the window.
        $(window).on('resize', Drupal.debounce(function () {
          initPager($pager, $slideshow);
        }, 300));
      }

      function initPager($pager, $slideshow) {
        setTimeout(function () {
          $slideshow.find('.slick-prev').before($pager);
        }, 200 );
      }
    }
  };

})(jQuery, Drupal, drupalSettings);
